Learn R Programming

DOEM (version 0.0.0.1)

PeMSD7_workday: PeMSD7 on workday

Description

The workday data in PeMSD7

Usage

data("PeMSD7_workday")

Arguments

Format

A data frame with 12384 observations on the following 20 variables.

X773656

a numeric vector

X760074

a numeric vector

X760080

a numeric vector

X716414

a numeric vector

X760101

a numeric vector

X760112

a numeric vector

X716419

a numeric vector

X716421

a numeric vector

X716424

a numeric vector

X765476

a numeric vector

X760167

a numeric vector

X716427

a numeric vector

X716431

a numeric vector

X716433

a numeric vector

X760187

a numeric vector

X760196

a numeric vector

X716440

a numeric vector

X760226

a numeric vector

X760236

a numeric vector

X716449

a numeric vector

Details

The workday data set only records traffic flow data on workdays.

References

Xu, D., Wei, C., Peng, P., Xuan, Q., Guo, H. Ge-gan: a novel deep learning framework for road traffic state estimation[J]. Transportation Research Part C Emerging Technologies, 2020, 117, 102635.

Examples

Run this code
# NOT RUN {
data(PeMSD7_workday)
## maybe str(PeMSD7_workday) ; plot(PeMSD7_workday) ...
# }

Run the code above in your browser using DataLab